@@ -37,13 +37,13 @@ MainWin::MainWin(QWidget *parent) :
 
     contactsList = contactManager->contacts();
 
-    qDebug() << "contacts:\n";
+    //qDebug() << "contacts:\n";
 
     for(int i = 0; i < contactsList.count(); ++i)
     {
         QList<QContactPhoneNumber> phoneNumbers = contactsList.at(i).details<QContactPhoneNumber>();
 
-        qDebug() << "contact: " << contactsList.at(i).displayLabel() << "number(s): ";
+        //qDebug() << "contact: " << contactsList.at(i).displayLabel() << "number(s): ";
         for(int j = 0; j < phoneNumbers.count(); ++j)
         {
             qDebug() << phoneNumbers.at(j).number();
@@ -53,8 +53,6 @@ MainWin::MainWin(QWidget *parent) :
     setDBus();
     setXProperties();
 
-
-
 #ifdef Q_WS_MAEMO_5
         setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 #else
@@ -99,13 +97,13 @@ void MainWin::_show()
 #endif
 
     if(isLocked)
-        hildonLockRotation(); // when phone is locked and hildon-home is active then hildon-desktop doesn't care about atom rotation properties
+        hildonLockRotation(); // when phone is locked and hildon-home is active then hildon-desktop doesn't care about xlib atom rotation properties
 }
 
 void MainWin::onIncommingCall(const QDBusObjectPath &path, const QString &number)
 {
     _show();
-    qDebug() << "path: " << path.path();
+    //qDebug() << "path: " << path.path();
     QtConcurrent::run(this, &MainWin::setContactDetails, number);
 }
 
@@ -117,7 +115,7 @@ void MainWin::setContactDetails(const QString &number)
     else {
         mainWidget->setNumber(number);
 
-        qDebug() << "incoming call: " << number;
+        //qDebug() << "incoming call: " << number;
 
         QList<QContactPhoneNumber> phoneNumbers;
 
@@ -128,7 +126,7 @@ void MainWin::setContactDetails(const QString &number)
             {
                 if(phoneNumbers.at(j).number().contains(number.right(7)))
                 {
-                    qDebug() << "found contact: " << contactsList.at(i).displayLabel();
+                    //qDebug() << "found contact: " << contactsList.at(i).displayLabel();
 
                     mainWidget->setName(contactsList.at(i).displayLabel());
                     return;
@@ -194,7 +192,7 @@ void MainWin::rejectCall()
 
 void MainWin::onContactManagerChanged()
 {
-    qDebug() <<  "contact manager changed";
+    qDebug() <<  "contacts manager changed";
     contactsList = contactManager->contacts();
 }
 
@@ -208,7 +206,7 @@ void MainWin::onCallStatusChanged(const uint &status)
 void MainWin::hideEvent(QHideEvent *)
 {
     mainWidget->setNumber("");
-    mainWidget->setName("Unknown");
+    mainWidget->setName(dgettext("rtcom-call-ui", "voip_fi_caller_information_unknown_caller"));
 }
 
 void MainWin::onLockChanged(const QString &msg)
@@ -299,3 +297,15 @@ void MainWin::setXProperties()
                     (unsigned char*)stateprop.data(), stateprop.count());
 }
 
+void MainWin::changeEvent(QEvent *event)
+{
+    if(event->type() == QEvent::ActivationChange)
+    {
+        if(isActiveWindow())
+        {
+            viewport()->update(); // probably fix for rare black window bug -> need testing
+            mainWidget->update(); //
+        }
+    }
+}
+
